--- a/01_SafeTlib/SafeTlibCD/MicroTestLib/src/Mtl_Trap.c	2016-02-16 19:18:06.000000000 -0800
+++ b/01_SafeTlib/SafeTlibCD/MicroTestLib/src/Mtl_Trap.c	2021-02-11 19:23:05.000000000 -0800
@@ -368,7 +368,7 @@
 /*  Description:        Registers a caller supplied Trap Handler for traps of a given   */
 /*                      Trap Class.                                                     */
 /*                                                                                      */
 /*  Arguments (In):     -class                : Trap Class for which to register a Trap */
 /*                                              Handler routine                         */
 /*                      -handler              : Trap Handler function pointer that is to*/
 /*                                              be called for traps of the given Trap   */
@@ -390,7 +390,7 @@
 /*                      calling TRAP_UnregisterTrapHandler.                             */
 /*                                                                                      */
 /****************************************************************************************/
-TRAP_ErrorType TRAP_RegisterTrapHandler(const uint8 class, const TRAP_TrapHandlerCbk handler)
+TRAP_ErrorType TRAP_RegisterTrapHandler(const uint8 cls, const TRAP_TrapHandlerCbk handler)
 {
   TRAP_ErrorType    result = TRAP_E_SUCCESS;
   uint8 CoreId;
@@ -403,7 +403,7 @@
     result = TRAP_E_UNINIT;
   }
   /* Parameter check:                                                                    */
-  else if (class >= (uint8)TRAP_CLASS_COUNT_TOTAL)
+  else if (cls >= (uint8)TRAP_CLASS_COUNT_TOTAL)
   {
     result = TRAP_E_PARAM;
   }
@@ -411,7 +411,7 @@
   {
     result = TRAP_E_PARAM;
   }
-  else if (NULL_PTR != trap_TrapHandlers[CoreId][class])
+  else if (NULL_PTR != trap_TrapHandlers[CoreId][cls])
   {
     /* There is already another Trap Handler associated with the given Trap Class:    */
     result = TRAP_E_EXISTS;
@@ -419,7 +419,7 @@
   else
   {
     /* Store the given Trap Handler to the local list:                                */
-    trap_TrapHandlers[CoreId][class] = handler;
+    trap_TrapHandlers[CoreId][cls] = handler;
   }
 
   return result;
@@ -431,7 +431,7 @@
 /*  Description:        Un-registers a previously registered Trap Handler for traps of  */
 /*                      a given Trap Class.                                             */
 /*                                                                                      */
 /*  Arguments (In):     -class       : Trap Class for which to un-register the          */
 /*                                     Trap Handler routine                             */
 /*  Arguments (Out):    <none>                                                          */
 /*  Arguments (InOut):  <none>                                                          */
@@ -451,7 +451,7 @@
 /*                      TRAP_RegisterTrapHandler.                                       */
 /*                                                                                      */
 /****************************************************************************************/
-TRAP_ErrorType TRAP_UnregisterTrapHandler(const uint8 class)
+TRAP_ErrorType TRAP_UnregisterTrapHandler(const uint8 cls)
 {
   TRAP_ErrorType    result = TRAP_E_SUCCESS;
   uint8 CoreId;
@@ -464,11 +464,11 @@
     result = TRAP_E_UNINIT;
   }
   /* Parameter check:                                                                 */
-  else if (class >= (uint8)TRAP_CLASS_COUNT_TOTAL)
+  else if (cls >= (uint8)TRAP_CLASS_COUNT_TOTAL)
   {
     result = TRAP_E_PARAM;
   }
-  else if (NULL_PTR == trap_TrapHandlers[CoreId][class])
+  else if (NULL_PTR == trap_TrapHandlers[CoreId][cls])
   {
     /* There is no Trap Handler associated with the given Trap Class:               */
     result = TRAP_E_NOT_EXISTS;
@@ -476,7 +476,7 @@
   else
   {
     /* Delete the given Trap Handler from the local list:                           */
-    trap_TrapHandlers[CoreId][class] = NULL_PTR;
+    trap_TrapHandlers[CoreId][cls] = NULL_PTR;
   }
 
   return result;
@@ -602,7 +602,7 @@
 
   /* Jump to the applications Trap Vector, if the STL did not register a Trap Handler   */
   /* for the current Trap Class.                                                        */
   /* All class 3 traps except CDU trap are forwarded to the applications Trap Vector,   */
   /* regardless, whether there is a STL trap handler registered or not. This is done    */
   /* because for some class 3 traps, function calls are no longer possible.             */
   if ((NULL_PTR == trap_TrapHandlers[CoreId][trapClass]) ||
@@ -368,7 +368,7 @@
 /*                      Trap Class.                                                     */
 /*                                                                                      */
-/*  Arguments (In):     -class                : Trap Class for which to register a Trap */
+/*  Arguments (In):     -cls                : Trap Class for which to register a Trap */
 /*                                              Handler routine                         */
 /*                      -handler              : Trap Handler function pointer that is to*/
@@ -431,7 +431,7 @@
 /*                      a given Trap Class.                                             */
 /*                                                                                      */
-/*  Arguments (In):     -class       : Trap Class for which to un-register the          */
+/*  Arguments (In):     -cls       : Trap Class for which to un-register the          */
 /*                                     Trap Handler routine                             */
 /*  Arguments (Out):    <none>                                                          */
@@ -602,7 +602,7 @@
   /* Jump to the applications Trap Vector, if the STL did not register a Trap Handler   */
   /* for the current Trap Class.                                                        */
-  /* All class 3 traps except CDU trap are forwarded to the applications Trap Vector,   */
+  /* All cls 3 traps except CDU trap are forwarded to the applications Trap Vector,   */
   /* regardless, whether there is a STL trap handler registered or not. This is done    */
   /* because for some class 3 traps, function calls are no longer possible.             */
